Interface: ExtendedPlugin | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ExtendedPlugin<TType, O, Model>

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType`
`O` | `AnyObject`
`Model` | `TooltipModel`<`TType`>

## # Hierarchy

- `ExtendedPlugin`

  ↳ `Plugin`

## # Methods

### # afterTooltipDraw

▸ `Optional` afterTooltipDraw(`chart`, `args`, `options`): `void`

`desc` Called after drawing the `tooltip`. Note that this hook will not be called if the tooltip drawing has been previously cancelled.

#### # Parameters

Name | Type | Description
--- | --- | ---
`chart` | `Chart`<keyof `ChartTypeRegistry`, (`number` | `ScatterDataPoint` | `BubbleDataPoint`)[], `unknown`> | The chart instance.
`args` | `Object` | The call arguments.
`args.tooltip` | `Model` | The tooltip.
`options` | `O` | The plugin options.

#### # Returns

`void`

#### # Defined in

index.esm.d.ts:2601
(opens new window)

### # beforeTooltipDraw

▸ `Optional` beforeTooltipDraw(`chart`, `args`, `options`): `boolean` | `void`

`desc` Called before drawing the `tooltip`. If any plugin returns `false`, the tooltip drawing is cancelled until another `render` is triggered.

#### # Parameters

Name | Type | Description
--- | --- | ---
`chart` | `Chart`<keyof `ChartTypeRegistry`, (`number` | `ScatterDataPoint` | `BubbleDataPoint`)[], `unknown`> | The chart instance.
`args` | `Object` | The call arguments.
`args.tooltip` | `Model` | The tooltip.
`options` | `O` | The plugin options.

#### # Returns

`boolean` | `void`

`false` to cancel the chart tooltip drawing.

#### # Defined in

index.esm.d.ts:2592
(opens new window)